pub struct EspTwaiFrame { /* private fields */ }Expand description
A RAM buffer for a TWAI frame.
Mirror image of the 13 TWAI_DATA_x_REG registers.
Implementations
Sourceimpl EspTwaiFrame
impl EspTwaiFrame
Sourcepub fn is_remote_request(&self) -> bool
pub fn is_remote_request(&self) -> bool
Remote Transmission Request (RTR): specifies whether content is a data frame or a remote request frame (on-demand polling).
Note: Remote request frames do not have a data payload, no matter their DLC.
Sourcepub fn is_self_reception(&self) -> bool
pub fn is_self_reception(&self) -> bool
Self Reception (SR): indicates whether content was sent by us (using the TWAI_SELF_RX_SEQ command) or received from the bus.
Sourcepub fn data_length_code(&self) -> usize
pub fn data_length_code(&self) -> usize
Data Length Code (DLC): specifies the number of data bytes for a data frame, or the number of data bytes requested by a remote frame.
Note: although no frame can have a payload longer than 8, the DLC can be greater than 8 in rare cases (payload length then is still 8).
Sourcepub fn data_length(&self) -> usize
pub fn data_length(&self) -> usize
Length of the data payload: 0 for a RTR frame, 8 if DLC > 8.
Sourcepub fn identifier(&self) -> Id
pub fn identifier(&self) -> Id
Frame Identifier: 11-bit long for a SFF frame, 29-bit long for an EFF frame.
Sourcepub fn data(&self) -> &[u8]
pub fn data(&self) -> &[u8]
Frame Data: data payload, 0 to 8 bytes long.
Returns a reference to a slice:
- empty in case of a Remote Transmission Request
- 8 bytes long in case DLC > 8
Sourcepub fn new(id: impl Into<Id>, data: &[u8]) -> Option<Self>
pub fn new(id: impl Into<Id>, data: &[u8]) -> Option<Self>
Create a new EspTwaiFrame with the specified ID and data payload.
Sourcepub fn new_remote(id: impl Into<Id>, dlc: usize) -> Option<Self>
pub fn new_remote(id: impl Into<Id>, dlc: usize) -> Option<Self>
Create a new EspTwaiFrame for a transmission request with the
specified ID and data length (DLC).
Sourcepub fn new_self_reception(id: impl Into<Id>, data: &[u8]) -> Option<Self>
pub fn new_self_reception(id: impl Into<Id>, data: &[u8]) -> Option<Self>
Create a new EspTwaiFrame ready for self-reception with the specified
ID and data payload.